package com.jh.boot;

import org.springframework.boot.autoconfigure.condition.ConditionalOnMissingBean;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.context.annotation.Bean;

import com.jh.boot.email.LocalEmailService;
import com.jh.boot.security.utils.TemplateEmailAuthServiceListener;
import com.jh.boot.template.HibernateTemplateLoader;
import com.jh.boot.template.HibernateLoaderTemplateService;
import com.jh.boot.template.TemplateEngine;
import com.jh.boot.template.TemplateLoader;
import com.jh.boot.template.TemplateService;
import com.jh.boot.template.handlebars.HandlebarsTemplateEngine;

public class JhBootApplication {

	@Bean
    @ConditionalOnProperty(value = "email.local.enabled", havingValue = "true", matchIfMissing = true)
	public LocalEmailService emailService() {
		return new LocalEmailService();
	}

	
    @Bean
    @ConditionalOnProperty(value = "security.auth.listener.email.enabled", havingValue = "true", matchIfMissing = true)
    public TemplateEmailAuthServiceListener authServiceListener() {
    	return new TemplateEmailAuthServiceListener();
    }
    
    @Bean
    @ConditionalOnMissingBean(TemplateEngine.class)
    public TemplateEngine templateEngine() {
    	return new HandlebarsTemplateEngine();
    }
    
    @Bean
    @ConditionalOnMissingBean(TemplateLoader.class)
    public TemplateLoader templateLoader() {
    	return new HibernateTemplateLoader();
    }
    
    @Bean
    @ConditionalOnMissingBean(TemplateService.class)
    public TemplateService templateService() {
    	return new HibernateLoaderTemplateService();
    }
    

}
