package com.jh.boot.attachment;

import java.util.List;

import javax.persistence.TypedQuery;

import org.springframework.stereotype.Repository;

import com.jh.boot.jpa.AbstractHibernateRepository;
import com.jh.boot.web.list.Page;
import com.jh.boot.web.list.PagingInfo;

/**
 * The Class AttachmentRepository.
 */
@Repository
public class AttachmentRepository extends AbstractHibernateRepository {

	
	/**
	 * Find for unit id and object.
	 *
	 * @param unitId the unit id
	 * @param objectType the object type
	 * @param objectId the object id
	 * @param paging the paging
	 * @return the page
	 */
	public Page<Attachment> findForUnitIdAndObject(Long unitId, String objectType, Long objectId, PagingInfo paging) {
		TypedQuery<Attachment> query = getListQuery(unitId, objectType, objectId);
		query.setFirstResult(paging.getPage() * paging.getPageSize());
		query.setMaxResults(paging.getPageSize());
		
		//return new Page<>(0, 0, 0, 0, null, objectType, null);
		//FIXME
		return Page.empty();
	}

	/**
	 * Find for unit id and object.
	 *
	 * @param unitId the unit id
	 * @param objectType the object type
	 * @param objectId the object id
	 * @return the list
	 */
	public List<Attachment> findForUnitIdAndObject(Long unitId, String objectType, Long objectId) {
		TypedQuery<Attachment> query = getListQuery(unitId, objectType, objectId);
		return query.getResultList();
	}

	
	protected TypedQuery<Attachment> getListQuery(Long unitId, String objectType, Long objectId) {
		String hql = "select a from Attachment a";
		if (unitId != null || objectType != null || objectId != null) {
			hql += " where ";
			if (unitId != null) {
				hql += " a.unitId = :unitId";
			}
			if (objectType != null) {
				hql += " a.objectType = :objectType";
			}
			if (objectId != null) {
				hql += " a.objectId = :objectId";
			}
		}
		
		TypedQuery<Attachment> query = entityManager.createQuery(hql, Attachment.class);
		if (unitId != null) {
			query.setParameter("unitId", unitId);
		}
		if (objectType != null) {
			query.setParameter("objectType", objectType);
		}
		if (objectId != null) {
			query.setParameter("objectId", objectId);
		}
		return query;
	}

	
    /**
     * Rename.
     *
     * @param unitId the unit id
     * @param objectType the object type
     * @param objectId the object id
     * @param attachmentId the attachment id
     * @param name the name
     */
    public void rename(Long attachmentId, String name) {
        Attachment a = findById(attachmentId);
        a.setName(name);
    }

	public Attachment findById(Long id) {
		return entityManager.find(Attachment.class, id);
	}
	
	
}
